body {
    background: #222222;
    color:#19c931;
}

.header {
    background: #393939;
    color: #19c931;
    height: 35px;
    line-height: 35px;
    font-weight: bold;
}

.navbar-nav {
    width:100%;
}

.navbar-nav li {
    width: 33.3333333%;
    text-align: center;
    margin: 0 auto;
}

.glyph-centered {
    display:block;
    text-align:center;
}

.list-group-item .glyphicon {
    text-align: right;
    float:right;
    width:14px;
}

.fixed-pixel-glyphicon {
    width: 31px;
}

td {
    max-width: 0;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}
th a {
    color:#3fe41e;
}

#playlist-song-modal-body span {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.btn:last-child {
    margin-bottom: 15px;
}

.drag-drop a {
    background-color: rgb(22, 22, 22);
}
.drag-drop .sortable-ghost {
    opacity: 0.4;
    background-color: #F4E2C9;
}

.drag-drop a:first-letter {
    text-transform: uppercase;
}

.validation-summary-valid.alert-danger {
    display: none;
}

.navbar-default {
    background-image: -webkit-linear-gradient(top,#393939 0,#393939 100%);
    background-image: -o-linear-gradient(top,#393939 0,#393939 100%);
    background-image: -webkit-gradient(linear,left top,left bottom,from(#393939),to(#393939));
    background-image: linear-gradient(to top,#393939 0,#393939 100%);
    background-color: #393939;
    border-color: #393939;
    border-radius: 0px;
}
.navbar-default .navbar-nav>.active>a {
    background-image: -webkit-linear-gradient(top,#0b3004 0,#0b3004 100%);
    background-image: -o-linear-gradient(top,#0b3004 0,#0b3004 100%);
    background-image: -webkit-gradient(linear,left top,left bottom,from(#0b3004),to(#0b3004));
    background-image: linear-gradient(to bottom,#0b3004 0,#0b3004 100%);
    background-color: #0b3004;
    border-radius: 0px;
    color:#19c931;
}

.navbar-default .navbar-nav>.active>a, .navbar-default .navbar-nav>.active>a:focus, .navbar-default .navbar-nav>.active>a:hover {
    color: #19c931;
}

.navbar-default .navbar-nav>li>a, .navbar-default .navbar-nav>li>a:focus, .navbar-default .navbar-nav>li>a:hover {
    color: #19c931;
}

.btn-secondary {
    background-color: #393939;
    color:#19c931;
}
.btn-secondary:hover {
    background-color: #0b3004;
    color:#19c931;
}

.table-striped > tbody > tr:nth-of-type(2n+1) {
  background-color: #313531;
}
.table-hover > tbody > tr:hover {
  background-color: #4b4b4b;
}

a.list-group-item, button.list-group-item {
  color: #19c931;
  background:#222222;
}


a.list-group-item:focus, a.list-group-item:hover, button.list-group-item:focus, button.list-group-item:hover {
  color: #19c931;
  text-decoration: none;
  background-color: #313531;
}

.modal-content {
  background: #202020;
}
.modal-header .close {
    color:white;
}

.dropdown-menu > li > a, .dropdown-menu {
    color: #19c931;
  background:#222222;
}

.dropdown-menu > .active > a, .dropdown-menu > .active > a:focus, .dropdown-menu > .active > a:hover {
    background-color: #4b4b4b;
    background-image: linear-gradient(to bottom,#4b4b4b 0,#4b4b4b 100%);
    color:#19c931;
}