html {
    min-height: 100%
}

body {
    color: #eee;
    background: linear-gradient(0deg, #4b6cb7 0%, #182848 100%);
}

.header {
    background: #111;
    color: #FFFFFF;
    line-height: 60px;
    font-weight: bold;
    border-bottom:1px solid #ccc;
}

.navbar-nav {
    width:100%;
}

.navbar-nav li {
    width: 33.3333333%;
    text-align: center;

    float:left;
}

.glyph-centered {
    display:block;
    text-align:center;
}

.list-group-item .glyphicon {
    text-align: right;
    float:right;
    width:14px;
}

/*.fixed-pixel-glyphicon {
    width: 31px;
}
*/

td {
    max-width: 0;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

#playlist-song-modal-body span {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.btn:last-child {
    margin-bottom: 15px;
}

.drag-drop a {
    background-color: #fff;
}
.drag-drop .sortable-ghost {
    opacity: 0.4;
    background-color: #F4E2C9;
}

.drag-drop a:first-letter {
    text-transform: uppercase;
}

.validation-summary-valid.alert-danger {
    display: none;
}

.navbar-default {
    background-image: -webkit-linear-gradient(top,#393939 0,#393939 100%);
    background-image: -o-linear-gradient(top,#393939 0,#393939 100%);
    background-image: -webkit-gradient(linear,left top,left bottom,from(#393939),to(#393939));
    background-image: linear-gradient(to top,#393939 0,#393939 100%);
    background-color: #393939;
    border-color: #393939;
    border-radius: 0px;
}
.navbar-default .navbar-nav>.active>a {
    background-image: -webkit-linear-gradient(top,#61A0CD 0,#61A0CD 100%);
    background-image: -o-linear-gradient(top,#61A0CD 0,##61A0CD 100%);
    background-image: -webkit-gradient(linear,left top,left bottom,from(#61A0CD),to(#61A0CD));
    background-image: linear-gradient(to bottom,#61A0CD 0,#61A0CD 100%);
    background-color: #61A0CD;
    border-radius: 0px;
}

.navbar-default .navbar-nav>.active>a, .navbar-default .navbar-nav>.active>a:focus, .navbar-default .navbar-nav>.active>a:hover {
    color: #FFFFFF;
}

.navbar-default .navbar-nav>li>a, .navbar-default .navbar-nav>li>a:focus, .navbar-default .navbar-nav>li>a:hover {
    color: #FFFFFF;
}

/* Performous+ */

.btn-secondary {
    width: 100%;
    margin: 0px auto 20px auto;
    background-color:#222;
    color:#ddd;
}

.btn-secondary:hover, btn-secondary:focus, btn-secondary:active {
    background-color: #61A0CD;
    color:#eee;
}

.btn-secondary > span {
    font-size:18pt;
}

.table-hover > tbody > tr:hover {
    background-color: #555;
}

.table {
    background-color:#333;
    color:#eee;
    border-radius:5px;
}

.table-striped > tbody > tr:nth-of-type(2n+1) {
    background-color: #222;
}
.table-striped > tbody > tr > td, .table > tbody > tr > td, .table > tbody > tr > th {
    border:none;
    line-height:3;
}
a {
  color: #eee;
  text-decoration: none;
}

.drag-drop a {
    background-color:#333;
    color:#eee;

}

.navbar-collapse > ul > li > a > span {
    font-size:24pt;
    line-height: 1.5;
}

.navbar-default .navbar-nav > .active > a, .navbar-default .navbar-nav > .active > a:focus {
    background-image: none;
    color: #61A0CD;
    background-color: transparent;
}

.navbar-default {
    background-image:none;
    background-color:transparent;
    border:none;
    box-shadow:none;
    -webkit-box-shadow:none;
}

.navbar-default .navbar-collapse {
  border-color: transparent;
}

.modal-content {
    background-color:#333
}

.list-group-item {
    background-color: transparent;
    border: 1px solid #ddd;
}
a.list-group-item{
    color:#eee;
}
